==> delphixpy-1.11.20.0.tar.gz: delphixpy-1.11.20.0/delphixpy/v1_11_17/web/role/role.py <==
#
# Copyright 2023 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "role"
"""
from delphixpy.v1_11_17 import response_validator

def create(engine, role=None):
    """
    Create a new Role object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
    :param role: Payload object.
    :type role: :py:class:`v1_11_17.web.vo.Role`
    :rtype: ``str``
    """
    url = "/resources/json/delphix/role"
    response = engine.post(url, role.to_dict(dirty=True) if role else None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)

def get(engine, ref):
    """
    Retrieve the specified Role object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_11_17.web.objects.Role.Role` object
    :type ref: ``str``
    :rtype: :py:class:`v1_11_17.web.vo.Role`
    """
    url = "/resources/json/delphix/role/%s" % ref
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['Role'], returns_list=False, raw_result=raw_result)

def get_all(engine):
    """
    Lists roles available in the system.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
    :rtype: ``list`` of :py:class:`v1_11_17.web.vo.Role`
    """
    url = "/resources/json/delphix/role"
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['Role'], returns_list=True, raw_result=raw_result)

def update(engine, ref, role=None):
    """
    Update the specified Role object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_11_17.web.objects.Role.Role` object
    :type ref: ``str``
    :param role: Payload object.
    :type role: :py:class:`v1_11_17.web.vo.Role`
    """
    url = "/resources/json/delphix/role/%s" % ref
    response = engine.post(url, role.to_dict(dirty=True) if role else None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)

def delete(engine, ref):
    """
    Delete the specified Role object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_11_17.web.objects.Role.Role` object
    :type ref: ``str``
    """
    url = "/resources/json/delphix/role/%s/delete" % ref
    response = engine.post(url, None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)

def auditor_role(engine):
    """
    Returns the auditor role.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
    :rtype: :py:class:`v1_11_17.web.vo.Role`
    """
    url = "/resources/json/delphix/role/auditorRole"
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['Role'], returns_list=False, raw_result=raw_result)

def provisioner_role(engine):
    """
    Returns the provisioner role.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
    :rtype: :py:class:`v1_11_17.web.vo.Role`
    """
    url = "/resources/json/delphix/role/provisionerRole"
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['Role'], returns_list=False, raw_result=raw_result)

def owner_role(engine):
    """
    Returns the owner role.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
    :rtype: :py:class:`v1_11_17.web.vo.Role`
    """
    url = "/resources/json/delphix/role/ownerRole"
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['Role'], returns_list=False, raw_result=raw_result)

def jet_stream_user_role(engine):
    """
    Returns the Self-Service user role.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
    :rtype: :py:class:`v1_11_17.web.vo.Role`
    """
    url = "/resources/json/delphix/role/jetStreamUserRole"
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['Role'], returns_list=False, raw_result=raw_result)

def self_service_user_role(engine):
    """
    Returns the Self-Service user role.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
    :rtype: :py:class:`v1_11_17.web.vo.Role`
    """
    url = "/resources/json/delphix/role/selfServiceUserRole"
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['Role'], returns_list=False, raw_result=raw_result)

==> delphixpy-1.11.26.0.tar.gz: delphixpy-1.11.26.0/delphixpy/v1_8_2/web/role/role.py <==
#
# Copyright 2023 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

"""
Package "role"
"""
from delphixpy.v1_8_2 import response_validator

def create(engine, role=None):
    """
    Create a new Role object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_8_2.delphix_engine.DelphixEngine`
    :param role: Payload object.
    :type role: :py:class:`v1_8_2.web.vo.Role`
    :rtype: ``str``
    """
    url = "/resources/json/delphix/role"
    response = engine.post(url, role.to_dict(dirty=True) if role else None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)

def get(engine, ref):
    """
    Retrieve the specified Role object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_8_2.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_8_2.web.objects.Role.Role` object
    :type ref: ``str``
    :rtype: :py:class:`v1_8_2.web.vo.Role`
    """
    url = "/resources/json/delphix/role/%s" % ref
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['Role'], returns_list=False, raw_result=raw_result)

def get_all(engine):
    """
    Lists roles available in the system.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_8_2.delphix_engine.DelphixEngine`
    :rtype: ``list`` of :py:class:`v1_8_2.web.vo.Role`
    """
    url = "/resources/json/delphix/role"
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['Role'], returns_list=True, raw_result=raw_result)

def update(engine, ref, role=None):
    """
    Update the specified Role object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_8_2.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_8_2.web.objects.Role.Role` object
    :type ref: ``str``
    :param role: Payload object.
    :type role: :py:class:`v1_8_2.web.vo.Role`
    """
    url = "/resources/json/delphix/role/%s" % ref
    response = engine.post(url, role.to_dict(dirty=True) if role else None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)

def delete(engine, ref):
    """
    Delete the specified Role object.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_8_2.delphix_engine.DelphixEngine`
    :param ref: Reference to a
        :py:class:`delphixpy.v1_8_2.web.objects.Role.Role` object
    :type ref: ``str``
    """
    url = "/resources/json/delphix/role/%s/delete" % ref
    response = engine.post(url, None)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)

def auditor_role(engine):
    """
    Returns the auditor role.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_8_2.delphix_engine.DelphixEngine`
    :rtype: :py:class:`v1_8_2.web.vo.Role`
    """
    url = "/resources/json/delphix/role/auditorRole"
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['Role'], returns_list=False, raw_result=raw_result)

def jet_stream_user_role(engine):
    """
    Returns the Jet Stream user role.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_8_2.delphix_engine.DelphixEngine`
    :rtype: :py:class:`v1_8_2.web.vo.Role`
    """
    url = "/resources/json/delphix/role/jetStreamUserRole"
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['Role'], returns_list=False, raw_result=raw_result)

def owner_role(engine):
    """
    Returns the owner role.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_8_2.delphix_engine.DelphixEngine`
    :rtype: :py:class:`v1_8_2.web.vo.Role`
    """
    url = "/resources/json/delphix/role/ownerRole"
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['Role'], returns_list=False, raw_result=raw_result)

def provisioner_role(engine):
    """
    Returns the provisioner role.

    :param engine: The Delphix Engine
    :type engine: :py:class:`delphixpy.v1_8_2.delphix_engine.DelphixEngine`
    :rtype: :py:class:`v1_8_2.web.vo.Role`
    """
    url = "/resources/json/delphix/role/provisionerRole"
    response = engine.get(url)
    result = response_validator.validate(response, engine)
    raw_result = getattr(engine, 'raw_result', False)
    return response_validator.parse_result(result, undef_enabled=True, return_types=['Role'], returns_list=False, raw_result=raw_result)
